@@ -26,7 +26,7 @@ sub from_arguments_to_choices {
     my $invalid_char = $opt->{invalid_char};
     my $more = 0;
     for my $id ( @ids ) {
-        $opt->{view_count_length} = 0;
+        $opt->{length_view_count} = 0;
         if ( my $channel_id = _user_id( $opt, $id ) ) {
             my $tmp = _id_to_tmp_info_hash( $opt, 'CL', $channel_id );
             my $ex = 'youtube';
@@ -176,7 +176,7 @@ sub _id_to_tmp_info_hash {
             last;
         }
         for my $entry ( @$entries ) {
-            add_entry_to_info_hash( $opt, $tmp, $entry, $type, $list_id ); #
+            add_entry_to_info_hash( $opt, $tmp, $entry, $type, $list_id );
         }
         if ( $opt->{nr_of_latest_videos} && $start_index > $opt->{nr_of_latest_videos} ) {
             last;
@@ -214,7 +214,7 @@ sub _more_url_to_tmp_info_hash {
 sub _non_yt_id_to_tmp_info_hash {
     my ( $opt, $id ) = @_;
     my $message = "Fetching download info: ";
-    my $json_all = get_download_info_as_json( $opt, $id, $message ); # extractor?
+    my $json_all = get_download_info_as_json( $opt, $id, $message );
     my $tmp = {};
     return $tmp if ! $json_all;
     for my $json ( split /\n+/, $json_all ) {
