@@ -54,9 +54,9 @@ sub choose_videos {
             $title =~ s/\s+/ /g;
             $title =~ s/^\s+|\s+\z//g;
             if ( length $regexp ) {
-                if ( $regexp =~ /^!~(.+)\z/ ) {
+                if ( $regexp =~ /^!~\s(.+)\z/ ) {
                     my $r = $1;
-                    if ( $title =~ /$r/ ) {
+                    if ( $title =~ /$r/i ) {
                         next VIDEO_ID;
                     }
                 }
@@ -70,7 +70,7 @@ sub choose_videos {
                 #$tmp->{$ex}{$video_id}{extractor_key} = 'Youtube';
             }
             if ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} ) {
-                push @videos, sprintf "%11s | %7s  %10s  %$opt->{view_count_length}s  %s", $video_id,
+                push @videos, sprintf "%11s | %7s  %10s  %$opt->{length_view_count}s  %s", $video_id,
                     $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date}, $tmp->{$ex}{$video_id}{view_count}, $title;
             }
             else {
@@ -144,7 +144,6 @@ sub choose_videos {
             }
             else {
                 return;
-                #last FILTER;
             }
         }
     }
