@@ -56,10 +56,6 @@ sub add_entry_to_info_hash {
     if ( $info->{$ex}{$video_id}{author_uri} && $info->{$ex}{$video_id}{author_uri} =~ m|/users/([^$opt->{invalid_char}]+)| ) {
         $info->{$ex}{$video_id}{uploader_id} = $1;
     }
-    if ( $info->{$ex}{$video_id}{published} && $info->{$ex}{$video_id}{published} =~ /^(\d\d\d\d-\d\d-\d\d)T(\d\d:\d\d:\d\d)/ ) {
-        $info->{$ex}{$video_id}{upload_date} = $1;
-        $info->{$ex}{$video_id}{upload_datetime} = $1 . 'T' . $2;
-    }
     if ( defined $type && $type eq 'PL' ) {
         $info->{$ex}{$video_id}{playlist_id} = $list_id;
     }
@@ -85,14 +81,10 @@ sub json_to_hash {
     if ( $ex =~ /^youtube\z/i ) {
         $ex = 'youtube';
     }
-    if ( %$tmp && ! $ex ) {
-        $ex = 'youtube';
-    }
     if ( ! length $ex ) {
         $ex = 'unkown_etractor';
     }
     my $video_id = $h_ref->{id} // $h_ref->{title};
-    $tmp->{$ex}{$video_id}{video_id} = $video_id; #
     my @keys = ( qw( uploader uploader_id description format_id dislike_count dislike_count
                     duration extractor extractor_key like_count playlist_id title upload_date view_count ) );
                     # age_limit annotations fulltitle playlist stitle categories
@@ -102,8 +94,8 @@ sub json_to_hash {
         }
     }
     if ( $tmp->{$ex}{$video_id}{upload_date} && $tmp->{$ex}{$video_id}{upload_date} =~ /^(\d{4})(\d{2})(\d{2})\z/ ) {
-            $tmp->{$ex}{$video_id}{upload_date}     = $1 . '-' . $2 . '-' . $3;
-            $tmp->{$ex}{$video_id}{upload_datetime} = $1 . '-' . $2 . '-' . $3 . 'T00:00:00';
+        $tmp->{$ex}{$video_id}{upload_date}     = $1 . '-' . $2 . '-' . $3;
+        $tmp->{$ex}{$video_id}{upload_datetime} = $1 . '-' . $2 . '-' . $3 . 'T00:00:00';
     }
     $tmp->{$ex}{$video_id}{fmt_to_info} = $formats;
     _prepare_info_hash( $opt, $tmp, $ex, $video_id );
@@ -121,7 +113,10 @@ sub _prepare_info_hash {
     $info->{$ex}{$video_id}{playlist_id} //= '';
     $info->{$ex}{$video_id}{uploader}    //= $info->{$ex}{$video_id}{uploader_id} // '';
     #$info->{$ex}{$video_id}{extractor_key} //= $info->{$ex}{$video_id}{extractor} // '';
-
+    if ( $info->{$ex}{$video_id}{published} && $info->{$ex}{$video_id}{published} =~ /^(\d\d\d\d-\d\d-\d\d)T(\d\d:\d\d:\d\d)/ ) {
+        $info->{$ex}{$video_id}{upload_date} = $1;
+        $info->{$ex}{$video_id}{upload_datetime} = $1 . 'T' . $2;
+    }
     if ( $info->{$ex}{$video_id}{duration} =~ /^[0-9]+\z/ ) {
         $info->{$ex}{$video_id}{duration} = sec_to_time( $info->{$ex}{$video_id}{duration}, 1 );
     }
@@ -138,8 +133,8 @@ sub _prepare_info_hash {
     if ( $info->{$ex}{$video_id}{view_count} ) {
         $info->{$ex}{$video_id}{view_count_raw} = $info->{$ex}{$video_id}{view_count} // 0;
         $info->{$ex}{$video_id}{view_count} = insert_sep( $info->{$ex}{$video_id}{view_count} );
-        if ( length $info->{$ex}{$video_id}{view_count} > $opt->{view_count_length} ) {
-            $opt->{view_count_length} = length $info->{$ex}{$video_id}{view_count}; #
+        if ( length $info->{$ex}{$video_id}{view_count} > $opt->{length_view_count} ) {
+            $opt->{length_view_count} = length $info->{$ex}{$video_id}{view_count};
         }
     }
 }
