@@ -27,6 +27,59 @@ use App::YTDL::Helper qw( encode_fs write_json read_json HIDE_CURSOR SHOW_CURSOR
 
 
 
+sub _show_info {
+    my ( $opt ) = @_;
+    my ( $youtube_dl_version, $ffmpeg_version, $ffprobe_version );
+    try {
+        my $youtube_dl = which( 'youtube-dl' ) // 'youtube-dl';
+        $youtube_dl_version = capture( $youtube_dl, '--version' );
+    }
+    catch {
+        $youtube_dl_version = $_;
+    };
+    try {
+        my $ffmpeg = which( 'ffmpeg' );
+        $ffmpeg_version = capture( $ffmpeg, '-version' );
+        if ( $ffmpeg_version =~ /^ffmpeg version (\S+)/m ) {
+            $ffmpeg_version = $1;
+        }
+        else {
+            $ffmpeg_version = '';
+        }
+    };
+    try {
+        my $ffprobe = which( 'ffprobe' );
+        $ffprobe_version = capture( $ffprobe, '-version' );
+        if ( $ffprobe_version =~ /^ffprobe version (\S+)/m ) {
+            $ffprobe_version = $1;
+        }
+        else {
+            $ffprobe_version = '';
+        }
+    };
+    my $version     = '  version ';
+    my $bin         = '    bin   ';
+    my $video_dir   = ' video dir';
+    my $config_dir  = 'config dir';
+    my $youtube_dl  = 'youtube-dl';
+    my $ffmpeg      = '  ffmpeg  ';
+    my $ffprobe     = '  ffprobe ';
+    my $path = {
+        $version    => $main::VERSION,
+        $bin        => catfile( $RealBin, $RealScript ),
+        $video_dir  => $opt->{video_dir},
+        $config_dir => $opt->{config_dir},
+        $youtube_dl => $youtube_dl_version // 'error',
+        $ffmpeg     => $ffmpeg_version,
+        $ffprobe    => $ffprobe_version,
+    };
+    my $keys = [ $bin, $version, $video_dir, $config_dir, $youtube_dl ];
+    push @$keys, $ffmpeg  if $ffmpeg_version;
+    push @$keys, $ffprobe if $ffprobe_version;
+    print_hash( $path, { keys => $keys, preface => ' Close with ENTER' } );
+}
+
+
 sub _menus {
     my $menus = {
         main => [
@@ -49,16 +102,16 @@ sub _menus {
             [ 'timeout',        "- Timeout"          ],
         ],
         group_merge => [
-            [ 'merge_enabled',    "- Enable Merge"     ],
+            [ 'merge_enabled',    "- Enable Merge"      ],
             [ 'merge_overwrite',  "- ffmpeg overwrites" ],
-            [ 'merge_ext',        "- Output formats"   ],
-            [ 'merge_loglevel',   "- Verbosity"        ],
-            [ 'merged_in_files',  "- Input files"      ],
+            [ 'merge_ext',        "- Output formats"    ],
+            [ 'merge_loglevel',   "- Verbosity"         ],
+            [ 'merged_in_files',  "- Input files"       ],
         ],
         group_quality => [
-            [ 'auto_quality',    "- Auto quality mode"   ],
-            [ 'print_pref_qual', "- Preferred qualities" ],
-            [ 'pref_qual_slots', "- Slots 'preferred qualilties'"    ],
+            [ 'auto_quality',    "- Auto quality mode"            ],
+            [ 'print_pref_qual', "- Preferred qualities"          ],
+            [ 'pref_qual_slots', "- Slots 'preferred qualilties'" ],
         ],
         group_history => [
             [ 'log_info',             "- Logging"         ],
@@ -75,13 +128,13 @@ sub _menus {
             [ 'modify_timestamp', "- File timestamp"      ],
         ],
         group_list_menu => [
-            [ 'list_size_idx',   "- List size" ],
-            [ 'list_sort_item',  "- Sort order"      ],
+            [ 'list_size_idx',   "- List size"  ],
+            [ 'list_sort_item',  "- Sort order" ],
             [ 'show_view_count', "- View count" ],
         ],
         group_output => [
-            [ 'max_info_width',  "- Max info width"  ],
-            [ 'kb_sec_len',      "- Digits 'k/s'"    ],
+            [ 'max_info_width',  "- Max info width" ],
+            [ 'kb_sec_len',      "- Digits 'k/s'"   ],
         ],
     };
     return $menus;
@@ -165,51 +218,7 @@ sub set_options {
                 pod2usage( { -exitval => 'NOEXIT', -verbose => 2 } );
             }
             elsif ( $choice eq "show_info" ) {
-                my ( $youtube_dl_version, $ffmpeg_version, $ffprobe_version );
-                try {
-                    my $youtube_dl = which( 'youtube-dl' );
-                    $youtube_dl_version = capture( $youtube_dl, '--version' );
-                };
-                try {
-                    my $ffmpeg = which( 'ffmpeg' );
-                    $ffmpeg_version = capture( $ffmpeg, '-version' );
-                    if ( $ffmpeg_version =~ /^ffmpeg version (\S+)/m ) {
-                        $ffmpeg_version = $1;
-                    }
-                    else {
-                        $ffmpeg_version = '';
-                    }
-                };
-                try {
-                    my $ffprobe = which( 'ffprobe' );
-                    $ffprobe_version = capture( $ffprobe, '-version' );
-                    if ( $ffprobe_version =~ /^ffprobe version (\S+)/m ) {
-                        $ffprobe_version = $1;
-                    }
-                    else {
-                        $ffprobe_version = '';
-                    }
-                };
-                my $version     = '  version ';
-                my $bin         = '    bin   ';
-                my $video_dir   = ' video dir';
-                my $config_dir  = 'config dir';
-                my $youtube_dl  = 'youtube-dl';
-                my $ffmpeg      = '  ffmpeg  ';
-                my $ffprobe     = '  ffprobe ';
-                my $path = {
-                    $version    => $main::VERSION,
-                    $bin        => catfile( $RealBin, $RealScript ),
-                    $video_dir  => $opt->{video_dir},
-                    $config_dir => $opt->{config_dir},
-                    $youtube_dl => $youtube_dl_version // 'error',
-                    $ffmpeg     => $ffmpeg_version,
-                    $ffprobe    => $ffprobe_version,
-                };
-                my $keys = [ $bin, $version, $video_dir, $config_dir, $youtube_dl ];
-                push @$keys, $ffmpeg  if $ffmpeg_version;
-                push @$keys, $ffprobe if $ffprobe_version;
-                print_hash( $path, { keys => $keys, preface => ' Close with ENTER' } );
+                _show_info( $opt );
             }
             elsif ( $choice eq "list_extractors" ) {
                 print HIDE_CURSOR;
@@ -231,9 +240,8 @@ sub set_options {
                     );
                 }
             }
-
             elsif ( $choice eq "useragent" ) {
-                my $prompt = 'Set the UserAgent.';
+                my $prompt = 'Set the UserAgent';
                 my $list = [
                     [ 'UserAgent', $opt->{useragent} ]
                 ];
@@ -243,7 +251,10 @@ sub set_options {
             }
             elsif ( $choice eq "overwrite" ) {
                 my $prompt = 'Overwrite files';
-                my $list = [ qw( NO YES ) ];
+                my $list = [
+                    'Append if incomplete',
+                    'Overwrite'
+                ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "retries" ) {
@@ -368,7 +379,7 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "list_size_idx" ) {
-                my $prompt = 'Youtube videos per channel/playlist:';
+                my $prompt = 'Youtube videos per channel/playlist';
                 my $list = [
                     'All',
                     'Latest 50',
@@ -447,7 +458,9 @@ sub _opt_number_range {
     $current = insert_sep( $current );
     # Choose_a_number
     my $choice = choose_a_number( $digits, { name => $prompt, current => $current } );
-    return if ! defined $choice;
+    if ( ! defined $choice ) {
+        return;
+    }
     $opt->{$section} = $choice eq '--' ? undef : $choice;
     $opt->{change}++;
     return;
@@ -461,7 +474,7 @@ sub _opt_choose_from_list_idx {
     my @pre = ( undef, $confirm );
     my $choices = [ @pre, map { "- $_" } @$list ];
     while ( 1 ) {
-        my $local_prompt = $prompt . ' [' . ( $list->[$opt->{$section}] // '--' ) . ']';
+        my $local_prompt = $prompt . ': [' . ( $list->[$opt->{$section}] // '--' ) . ']';
         my $idx = choose(
             $choices,
             { prompt => $local_prompt, layout => 3, undef => '  BACK', index => 1 }
@@ -485,7 +498,7 @@ sub _opt_choose_from_list_value {
     my $confirm = '  CONFIRM';
     my @pre = ( undef, $confirm );
     while ( 1 ) {
-        my $local_prompt = $prompt . ' [' . ( $opt->{$section} // '--' ) . ']';
+        my $local_prompt = $prompt . ': [' . ( $opt->{$section} // '--' ) . ']';
         my $choice = choose(
             [ @pre,  map { "- $_" } @$list ],
             { prompt => $local_prompt, layout => 3, undef => '  BACK', index => 0 }
@@ -517,12 +530,12 @@ sub sort_order_list {
     my $confirm = '  CONFIRM';
     my @pre = ( undef, $confirm );
     my $choices = [ @pre, map( "- $_->{prompt}", @$sort_items ) ];
-    my $idx;
+    my $tmp;
 
     while ( 1 ) {
         my $first_index = first_index { $_->{key} eq $opt->{list_sort_item} } @$sort_items;
-        my $prompt = sprintf 'Sort item [%s]:', $sort_items->[$first_index]{prompt};
-        $idx = choose (
+        my $prompt = sprintf 'Sort item: [%s]', $sort_items->[$first_index]{prompt};
+        my $idx = choose (
             $choices,
             { prompt => $prompt, clear_screen => 0, layout => 3, index => 1, undef => '  BACK' }
         );
@@ -536,13 +549,14 @@ sub sort_order_list {
         }
         $idx -= @pre;
         $opt->{list_sort_item} = $sort_items->[$idx]{key};
+        $tmp                   = $sort_items->[$idx]{prompt};
     }
 
     while ( 1 ) {
-        my $order_prompt = sprintf 'Sort order %s [%s]:', $sort_items->[$idx]{prompt}, $opt->{list_sort_order};
+        my $order_prompt = sprintf 'Sort order "%s": [%s]', $tmp, $opt->{list_sort_order};
         my $choice = choose (
-            [ @pre, '- Desc', '- Asc' ],
-            { prompt => $order_prompt, clear_screen => 0, layout => 3, undef => '<<' }
+            [ @pre, '- Asc', '- Desc' ],
+            { prompt => $order_prompt, clear_screen => 0, layout => 3, undef => '  BACK' }
         );
         if ( ! defined $choice ) {
             $opt->{list_sort_order} = $backup_order;
@@ -560,7 +574,9 @@ sub sort_order_list {
 
 sub _write_config_file {
     my ( $opt, $file, @keys ) = @_;
-    return if ! $opt->{change};
+    if ( ! $opt->{change} ) {
+        return;
+    }
     my $tmp = {};
     for my $section ( sort @keys ) {
         $tmp->{$section} = $opt->{$section};
